@@ -22,10 +22,12 @@ def main_goose():
     CHANGE_IMG = pygame.USEREVENT + 3
     pygame.time.set_timer(CHANGE_IMG, 125)
 
-#test_version_powerhouse_helper\\GameGooseKiller\\image\\background
-    print(os.path.abspath('test_version_powerhouse_helper'))
+    root_dir_path = os.path.abspath('test_version_powerhouse_helper')
+    print(root_dir_path)
+    print(os.listdir(os.getcwd()))
+    print(list(os.walk(os.getcwd())))
 
-    BG_PATH = 'test_version_powerhouse_helper\\GameGooseKiller\\image\\background'  # 'test_version_powerhouse_helper', 'GameGooseKiller',
+    BG_PATH = os.path.join(root_dir_path, 'GameGooseKiller', 'image', 'background') # 'test_version_powerhouse_helper', 'GameGooseKiller',
 
     BG_images = [
         pygame.image.load(os.path.join(BG_PATH, file)).convert() for file in os.listdir(BG_PATH)
